==> leoo_junpro-1.0.1.tar.gz: lib/leooimpjunpro/leoosetjunpro/leoopermissionjunpro.dart <==
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_background/flutter_background.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooproviderjunpro/leoouserproviderjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoodialogutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoobuttonwidgetjunpro.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:provider/provider.dart';
import 'package:sp_util/sp_util.dart';

///设置-权限
class LeooPermissionJunPro extends StatefulWidget {
  const LeooPermissionJunPro({Key? key}) : super(key: key);

  @override
  _LeooSettingState createState() => _LeooSettingState();
}

class _LeooSettingState extends State<LeooPermissionJunPro>
    with WidgetsBindingObserver {
  PermissionStatus? statusNotification;
  PermissionStatus? statusSystemAlertWindow;
  PermissionStatus? statusBattery;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    getPermission();
  }

  @override
  void dispose() {
    WidgetsBinding.instance?.removeObserver(this);
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      getPermission();
    }
  }

  Future setPermission(bool open) async {
    try {
      if (open) {
        await FlutterBackground.enableBackgroundExecution();
      } else {
        await FlutterBackground.disableBackgroundExecution();
      }
      getPermission();
    } catch (e) {
      LeooNetConfigJunPro.leooPrintLogJunPro(e);
    }
  }

  void getPermission() async {
    statusNotification = await Permission.notification.status;
    statusSystemAlertWindow = await Permission.systemAlertWindow.status;
    statusBattery = await Permission.ignoreBatteryOptimizations.status;
    LeooCodeUtilsJunPro.onSetState(this);
    SpUtil.putBool(LeooAppConfigJunPro.leooBackgroundJunPro,
        FlutterBackground.isBackgroundExecutionEnabled);
  }

  Future<bool> getBackground() async {
    try {
      final androidConfig = FlutterBackgroundAndroidConfig(
        notificationTitle: LeooNetConfigJunPro.leooAppNameJunPro,
        notificationText:
            S.of(context).backgroundTip(LeooNetConfigJunPro.leooAppNameJunPro),
        notificationImportance: AndroidNotificationImportance.Default,
        notificationIcon:
            const AndroidResource(name: 'ic_launcher', defType: 'drawable'),
      );
      return await FlutterBackground.initialize(androidConfig: androidConfig);
    } catch (e) {
      LeooNetConfigJunPro.leooPrintLogJunPro(e);
      return false;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<LeooUserProviderJunPro>(
        builder: (_, LeooUserProviderJunPro userProvider, __) {
      return Scaffold(
        resizeToAvoidBottomInset: false,
        body: SafeArea(
          maintainBottomViewPadding: true,
          child: Column(
            children: <Widget>[
              LeooWidgetUtilsJunPro.leooGetAppBarWidgetJunPro(
                  context, S.of(context).permission),
              Expanded(
                child: SingleChildScrollView(
                  physics: const BouncingScrollPhysics(),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      if (Platform.isAndroid) SizedBox(height: 20.w),
                      if (Platform.isAndroid)
                        LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                          LeooIconsJunPro.leooMineNotificationJunPro,
                          width: 60.w,
                          height: 60.w,
                        ),
                      if (Platform.isAndroid)
                        Padding(
                          padding: EdgeInsets.all(15.w),
                          child: Text(
                            S.of(context).permissionBackTip,
                            style: LeooTextJunPro.leooGetTextStyleJunPro(
                                16, FontWeight.bold),
                            textAlign: TextAlign.center,
                          ),
                        ),
                      if (Platform.isAndroid)
                        CupertinoSwitch(
                          value: FlutterBackground.isBackgroundExecutionEnabled,
                          onChanged: (open) async {
                            if (open) {
                              bool init = await getBackground();
                              if (init) {
                                setPermission(true);
                              }
                            } else {
                              LeooCodeUtilsJunPro.onSetState(this);
                              LeooDialogUtilsJunPro.instance
                                  .showCustomDialog(context,
                                      content:
                                          S.of(context).permissionBackClose,
                                      right: S.of(context).appClose)
                                  .then((value) async {
                                if (value == true) {
                                  bool init = await getBackground();
                                  if (init) {
                                    setPermission(false);
                                  }
                                }
                              });
                            }
                          },
                        ),
                      if (Platform.isAndroid) SizedBox(height: 20.w),
                      Padding(
                        padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                        child: Row(
                          children: [
                            Expanded(
                              child: Text(
                                S.of(context).permissionNotification,
                                style: LeooTextJunPro.leooGetTextStyleJunPro(
                                    16, FontWeight.bold),
                              ),
                            ),
                            CupertinoSwitch(
                              value: statusNotification ==
                                  PermissionStatus.granted,
                              onChanged: (open) async {
                                if (statusNotification ==
                                    PermissionStatus.granted) {
                                  LeooCommonUtilsJunPro
                                      .leooShowCustomToastJunPro(
                                          S.of(context).permissionOpen);
                                } else {
                                  statusNotification =
                                      await Permission.notification.request();
                                  LeooCodeUtilsJunPro.onSetState(this);
                                  if (statusNotification ==
                                      PermissionStatus.denied) {
                                    LeooDialogUtilsJunPro.instance
                                        .showCustomDialog(context,
                                            content: S
                                                .of(context)
                                                .permissionNotificationTip,
                                            right: S.of(context).appGo)
                                        .then((value) {
                                      if (value == true) {
                                        openAppSettings();
                                      }
                                    });
                                  }
                                }
                              },
                            ),
                          ],
                        ),
                      ),
                      if (Platform.isAndroid)
                        Padding(
                          padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                          child: Row(
                            children: [
                              Expanded(
                                child: Text(
                                  S.of(context).permissionBattery,
                                  style: LeooTextJunPro.leooGetTextStyleJunPro(
                                      16, FontWeight.bold),
                                ),
                              ),
                              CupertinoSwitch(
                                value:
                                    statusBattery == PermissionStatus.granted,
                                onChanged: (open) async {
                                  if (statusBattery ==
                                      PermissionStatus.granted) {
                                    LeooCommonUtilsJunPro
                                        .leooShowCustomToastJunPro(
                                            S.of(context).permissionOpen);
                                  } else {
                                    statusBattery = await Permission
                                        .ignoreBatteryOptimizations
                                        .request();
                                    LeooCodeUtilsJunPro.onSetState(this);
                                  }
                                },
                              ),
                            ],
                          ),
                        ),
                      if (Platform.isAndroid)
                        Padding(
                          padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                          child: Row(
                            children: [
                              Expanded(
                                child: Text(
                                  S.of(context).permissionWindow,
                                  style: LeooTextJunPro.leooGetTextStyleJunPro(
                                      16, FontWeight.bold),
                                ),
                              ),
                              CupertinoSwitch(
                                value: statusSystemAlertWindow ==
                                    PermissionStatus.granted,
                                onChanged: (open) async {
                                  if (statusSystemAlertWindow ==
                                      PermissionStatus.granted) {
                                    LeooCommonUtilsJunPro
                                        .leooShowCustomToastJunPro(
                                            S.of(context).permissionOpen);
                                  } else {
                                    statusSystemAlertWindow = await Permission
                                        .systemAlertWindow
                                        .request();
                                    LeooCodeUtilsJunPro.onSetState(this);
                                  }
                                },
                              ),
                            ],
                          ),
                        ),
                      LeooButtonWidgetJunPro(
                        S.of(context).permissionApp,
                        LeooTextJunPro.leooGetTextStyleJunPro(
                            16, FontWeight.bold),
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        iconData: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                          LeooIconsJunPro.leooMineRightJunPro,
                          width: 40.w,
                          height: 40.w,
                        ),
                        padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                        right: true,
                        textExpanded: true,
                        onPressed:
                            LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                          openAppSettings();
                        }),
                      ),
                    ],
                  ),
                ),
              )
            ],
          ),
        ),
      );
    });
  }
}

==> leoo_junpro-2.0.0.tar.gz: lib/leooimpjunpro/leoosetjunpro/leoopermissionjunpro.dart <==
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_background/flutter_background.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooproviderjunpro/leoouserproviderjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoodialogutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoobuttonwidgetjunpro.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:provider/provider.dart';
import 'package:sp_util/sp_util.dart';

///设置-权限
class LeooPermissionJunPro extends StatefulWidget {
  const LeooPermissionJunPro({Key? key}) : super(key: key);

  @override
  _LeooSettingState createState() => _LeooSettingState();
}

class _LeooSettingState extends State<LeooPermissionJunPro>
    with WidgetsBindingObserver {
  PermissionStatus? statusNotification;
  PermissionStatus? statusSystemAlertWindow;
  PermissionStatus? statusBattery;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
    getPermission();
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      getPermission();
    }
  }

  Future setPermission(bool open) async {
    try {
      if (open) {
        await FlutterBackground.enableBackgroundExecution();
      } else {
        await FlutterBackground.disableBackgroundExecution();
      }
      getPermission();
    } catch (e) {
      LeooNetConfigJunPro.leooPrintLogJunPro(e);
    }
  }

  void getPermission() async {
    statusNotification = await Permission.notification.status;
    statusSystemAlertWindow = await Permission.systemAlertWindow.status;
    statusBattery = await Permission.ignoreBatteryOptimizations.status;
    LeooCodeUtilsJunPro.onSetState(this);
    SpUtil.putBool(LeooAppConfigJunPro.leooBackgroundJunPro,
        FlutterBackground.isBackgroundExecutionEnabled);
  }

  Future<bool> getBackground() async {
    try {
      final androidConfig = FlutterBackgroundAndroidConfig(
        notificationTitle: LeooNetConfigJunPro.leooAppNameJunPro,
        notificationText:
            S.of(context).backgroundTip(LeooNetConfigJunPro.leooAppNameJunPro),
        notificationImportance: AndroidNotificationImportance.Default,
        notificationIcon:
            const AndroidResource(name: 'ic_launcher', defType: 'drawable'),
      );
      return await FlutterBackground.initialize(androidConfig: androidConfig);
    } catch (e) {
      LeooNetConfigJunPro.leooPrintLogJunPro(e);
      return false;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<LeooUserProviderJunPro>(
        builder: (_, LeooUserProviderJunPro userProvider, __) {
      return Scaffold(
        resizeToAvoidBottomInset: false,
        body: SafeArea(
          maintainBottomViewPadding: true,
          child: Column(
            children: <Widget>[
              LeooWidgetUtilsJunPro.leooGetAppBarWidgetJunPro(
                  context, S.of(context).permission),
              Expanded(
                child: SingleChildScrollView(
                  physics: const BouncingScrollPhysics(),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      if (Platform.isAndroid) SizedBox(height: 20.w),
                      if (Platform.isAndroid)
                        LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                          LeooIconsJunPro.leooMineNotificationJunPro,
                          width: 60.w,
                          height: 60.w,
                        ),
                      if (Platform.isAndroid)
                        Padding(
                          padding: EdgeInsets.all(15.w),
                          child: Text(
                            S.of(context).permissionBackTip,
                            style: LeooTextJunPro.leooGetTextStyleJunPro(
                                16, FontWeight.bold),
                            textAlign: TextAlign.center,
                          ),
                        ),
                      if (Platform.isAndroid)
                        CupertinoSwitch(
                          value: FlutterBackground.isBackgroundExecutionEnabled,
                          onChanged: (open) async {
                            if (open) {
                              bool init = await getBackground();
                              if (init) {
                                setPermission(true);
                              }
                            } else {
                              LeooCodeUtilsJunPro.onSetState(this);
                              LeooDialogUtilsJunPro.instance
                                  .showCustomDialog(context,
                                      content:
                                          S.of(context).permissionBackClose,
                                      right: S.of(context).appClose)
                                  .then((value) async {
                                if (value == true) {
                                  bool init = await getBackground();
                                  if (init) {
                                    setPermission(false);
                                  }
                                }
                              });
                            }
                          },
                        ),
                      if (Platform.isAndroid) SizedBox(height: 20.w),
                      Padding(
                        padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                        child: Row(
                          children: [
                            Expanded(
                              child: Text(
                                S.of(context).permissionNotification,
                                style: LeooTextJunPro.leooGetTextStyleJunPro(
                                    16, FontWeight.bold),
                              ),
                            ),
                            CupertinoSwitch(
                              value: statusNotification ==
                                  PermissionStatus.granted,
                              onChanged: (open) async {
                                if (statusNotification ==
                                    PermissionStatus.granted) {
                                  LeooCommonUtilsJunPro
                                      .leooShowCustomToastJunPro(
                                          S.of(context).permissionOpen);
                                } else {
                                  statusNotification =
                                      await Permission.notification.request();
                                  LeooCodeUtilsJunPro.onSetState(this);
                                  if (statusNotification ==
                                      PermissionStatus.denied) {
                                    LeooDialogUtilsJunPro.instance
                                        .showCustomDialog(context,
                                            content: S
                                                .of(context)
                                                .permissionNotificationTip,
                                            right: S.of(context).appGo)
                                        .then((value) {
                                      if (value == true) {
                                        openAppSettings();
                                      }
                                    });
                                  }
                                }
                              },
                            ),
                          ],
                        ),
                      ),
                      if (Platform.isAndroid)
                        Padding(
                          padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                          child: Row(
                            children: [
                              Expanded(
                                child: Text(
                                  S.of(context).permissionBattery,
                                  style: LeooTextJunPro.leooGetTextStyleJunPro(
                                      16, FontWeight.bold),
                                ),
                              ),
                              CupertinoSwitch(
                                value:
                                    statusBattery == PermissionStatus.granted,
                                onChanged: (open) async {
                                  if (statusBattery ==
                                      PermissionStatus.granted) {
                                    LeooCommonUtilsJunPro
                                        .leooShowCustomToastJunPro(
                                            S.of(context).permissionOpen);
                                  } else {
                                    statusBattery = await Permission
                                        .ignoreBatteryOptimizations
                                        .request();
                                    LeooCodeUtilsJunPro.onSetState(this);
                                  }
                                },
                              ),
                            ],
                          ),
                        ),
                      if (Platform.isAndroid)
                        Padding(
                          padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                          child: Row(
                            children: [
                              Expanded(
                                child: Text(
                                  S.of(context).permissionWindow,
                                  style: LeooTextJunPro.leooGetTextStyleJunPro(
                                      16, FontWeight.bold),
                                ),
                              ),
                              CupertinoSwitch(
                                value: statusSystemAlertWindow ==
                                    PermissionStatus.granted,
                                onChanged: (open) async {
                                  if (statusSystemAlertWindow ==
                                      PermissionStatus.granted) {
                                    LeooCommonUtilsJunPro
                                        .leooShowCustomToastJunPro(
                                            S.of(context).permissionOpen);
                                  } else {
                                    statusSystemAlertWindow = await Permission
                                        .systemAlertWindow
                                        .request();
                                    LeooCodeUtilsJunPro.onSetState(this);
                                  }
                                },
                              ),
                            ],
                          ),
                        ),
                      LeooButtonWidgetJunPro(
                        S.of(context).permissionApp,
                        LeooTextJunPro.leooGetTextStyleJunPro(
                            16, FontWeight.bold),
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        iconData: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                          LeooIconsJunPro.leooMineRightJunPro,
                          width: 40.w,
                          height: 40.w,
                        ),
                        padding: EdgeInsets.fromLTRB(15.w, 10.w, 15.w, 10.w),
                        right: true,
                        textExpanded: true,
                        onPressed:
                            LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                          openAppSettings();
                        }),
                      ),
                    ],
                  ),
                ),
              )
            ],
          ),
        ),
      );
    });
  }
}
